@@ -36,9 +36,7 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 #include <cairo/cairo-xlib.h>
-#endif
 
 #include "display.h"
 #include "screen.h"
@@ -2787,7 +2785,6 @@ xrender_process_event (MetaCompositor *compositor,
 #endif
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static cairo_surface_t *
 xrender_get_window_surface (MetaCompositor *compositor,
                             MetaWindow     *window)
@@ -2826,28 +2823,6 @@ xrender_get_window_surface (MetaCompositor *compositor,
                                     cw->attrs.width, cw->attrs.height);
 #endif
 }
-#else
-static Pixmap
-xrender_get_window_pixmap (MetaCompositor *compositor,
-                           MetaWindow     *window)
-{
-#ifdef HAVE_COMPOSITE_EXTENSIONS
-  MetaCompWindow *cw = NULL;
-  MetaScreen *screen = meta_window_get_screen (window);
-  MetaFrame *frame = meta_window_get_frame (window);
-
-  cw = find_window_for_screen (screen, frame ? meta_frame_get_xwindow (frame) :
-                               meta_window_get_xwindow (window));
-  if (cw == NULL)
-    return None;
-
-  if (meta_window_is_shaded (window))
-    return cw->shaded_back_pixmap;
-  else
-    return cw->back_pixmap;
-#endif
-}
-#endif  /* GTK_CHECK_VERSION */
 
 static void
 xrender_set_active_window (MetaCompositor *compositor,
@@ -3031,11 +3006,7 @@ static MetaCompositor comp_info = {
   xrender_remove_window,
   xrender_set_updates,
   xrender_process_event,
-#if GTK_CHECK_VERSION (3, 0, 0)
   xrender_get_window_surface,
-#else
-  xrender_get_window_pixmap,
-#endif
   xrender_set_active_window,
   xrender_maximize_window,
   xrender_unmaximize_window,
