@@ -85,6 +85,9 @@ struct _MetaScreen
 
   MetaWorkspace *active_workspace;
 
+  /* Previous active workspace */
+  MetaWorkspace *prev_workspace;
+
   /* This window holds the focus when we don't want to focus
    * any actual clients
    */
