@@ -1220,27 +1220,15 @@ get_window_pixbuf (MetaWindow *window,
                    int        *width,
                    int        *height)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   cairo_surface_t *surface;
-#else
-  Pixmap pmap;
-#endif
   GdkPixbuf *pixbuf, *scaled;
   double ratio;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   surface = meta_compositor_get_window_surface (window->display->compositor,
                                                 window);
   if (surface == None)
     return NULL;
-#else
-  pmap = meta_compositor_get_window_pixmap (window->display->compositor,
-                                            window);
-  if (pmap == None)
-    return NULL;
-#endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   meta_error_trap_push (NULL);
 
   pixbuf = meta_ui_get_pixbuf_from_surface (surface);
@@ -1248,9 +1236,6 @@ get_window_pixbuf (MetaWindow *window,
 
   if (meta_error_trap_pop_with_return (NULL, FALSE) != Success)
     g_clear_object (&pixbuf);
-#else
-  pixbuf = meta_ui_get_pixbuf_from_pixmap (pmap);
-#endif
 
   if (pixbuf == NULL)
     return NULL;
@@ -1288,6 +1273,7 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
   GList *tmp;
   int len;
   int i;
+  gint border;
 
   if (screen->tab_popup)
     return;
@@ -1304,6 +1290,8 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
   entries[len].title = NULL;
   entries[len].icon = NULL;
 
+  border = meta_prefs_show_tab_border() ? BORDER_OUTLINE_TAB |
+    BORDER_OUTLINE_WINDOW : BORDER_OUTLINE_TAB;
   i = 0;
   tmp = tab_list;
   while (i < len)
@@ -1368,38 +1356,43 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
        * sides.  On the top it should be the size of the south frame
        * edge.
        */
-#define OUTLINE_WIDTH 5
-      /* Top side */
-      if (!entries[i].hidden &&
-          window->frame && window->frame->bottom_height > 0 &&
-          window->frame->child_y >= window->frame->bottom_height)
-        entries[i].inner_rect.y = window->frame->bottom_height;
-      else
-        entries[i].inner_rect.y = OUTLINE_WIDTH;
+       if (border & BORDER_OUTLINE_WINDOW)
+         {
+           const gint border_outline_width = 5;
 
-      /* Bottom side */
-      if (!entries[i].hidden &&
-          window->frame && window->frame->bottom_height != 0)
-        entries[i].inner_rect.height = r.height
-          - entries[i].inner_rect.y - window->frame->bottom_height;
-      else
-        entries[i].inner_rect.height = r.height
-          - entries[i].inner_rect.y - OUTLINE_WIDTH;
+           /* Top side */
+           if (!entries[i].hidden &&
+                window->frame && window->frame->bottom_height > 0 &&
+                window->frame->child_y >= window->frame->bottom_height)
+             entries[i].inner_rect.y = window->frame->bottom_height;
+           else
+              entries[i].inner_rect.y = border_outline_width;
 
-      /* Left side */
-      if (!entries[i].hidden && window->frame && window->frame->child_x != 0)
-        entries[i].inner_rect.x = window->frame->child_x;
-      else
-        entries[i].inner_rect.x = OUTLINE_WIDTH;
+            /* Bottom side */
+            if (!entries[i].hidden &&
+                window->frame && window->frame->bottom_height != 0)
+              entries[i].inner_rect.height = r.height
+                - entries[i].inner_rect.y - window->frame->bottom_height;
+            else
+              entries[i].inner_rect.height = r.height
+                - entries[i].inner_rect.y - border_outline_width;
+
+            /* Left side */
+            if (!entries[i].hidden && window->frame && window->frame->child_x != 0)
+                entries[i].inner_rect.x = window->frame->child_x;
+            else
+                entries[i].inner_rect.x = border_outline_width;
+
+            /* Right side */
+            if (!entries[i].hidden &&
+                    window->frame && window->frame->right_width != 0)
+              entries[i].inner_rect.width = r.width
+                - entries[i].inner_rect.x - window->frame->right_width;
+            else
+              entries[i].inner_rect.width = r.width
+                - entries[i].inner_rect.x - border_outline_width;
+        }
 
-      /* Right side */
-      if (!entries[i].hidden &&
-          window->frame && window->frame->right_width != 0)
-        entries[i].inner_rect.width = r.width
-          - entries[i].inner_rect.x - window->frame->right_width;
-      else
-        entries[i].inner_rect.width = r.width
-          - entries[i].inner_rect.x - OUTLINE_WIDTH;
 
       ++i;
       tmp = tmp->next;
@@ -1409,7 +1402,7 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
                                              screen->number,
                                              len,
                                              5, /* FIXME */
-                                             TRUE);
+                                             border);
 
   for (i = 0; i < len; i++)
     g_object_unref (entries[i].icon);
@@ -1481,7 +1474,7 @@ meta_screen_ensure_workspace_popup (MetaScreen *screen)
                                              screen->number,
                                              len,
                                              layout.cols,
-                                             FALSE);
+                                             BORDER_OUTLINE_WORKSPACE);
 
   g_free (entries);
   meta_screen_free_workspace_layout (&layout);
@@ -2454,7 +2447,7 @@ queue_windows_showing (MetaScreen *screen)
     {
       MetaWindow *w = tmp->data;
 
-      if (w->screen == screen)
+      if (w->screen == screen && !meta_prefs_is_in_skip_list (w->res_class))
         meta_window_queue (w, META_QUEUE_CALC_SHOWING);
 
       tmp = tmp->next;
@@ -2508,7 +2501,8 @@ meta_screen_show_desktop (MetaScreen *screen,
       MetaWindow *w = windows->data;
 
       if (w->screen == screen  &&
-          w->type == META_WINDOW_DESKTOP)
+          w->type == META_WINDOW_DESKTOP &&
+          !meta_prefs_is_in_skip_list (w->res_class))
         {
           meta_window_focus (w, timestamp);
           break;
