@@ -75,11 +75,7 @@ struct _MetaUIFrame
 {
   Window xwindow;
   GdkWindow *window;
-#if GTK_CHECK_VERSION(3, 0, 0)
   GtkStyleContext *style;
-#else
-  GtkStyle *style;
-#endif
   MetaFrameStyle *cache_style;
   PangoLayout *layout;
   int text_height;
@@ -93,11 +89,7 @@ struct _MetaUIFrame
 
 struct _MetaFrames
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   GtkInvisible parent_instance;
-#else
-  GtkWindow parent_instance;
-#endif
 
   GHashTable *text_heights;
 
@@ -115,11 +107,7 @@ struct _MetaFrames
 
 struct _MetaFramesClass
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   GtkInvisibleClass parent_class;
-#else
-  GtkWindowClass parent_class;
-#endif
 };
 
 GType        meta_frames_get_type               (void) G_GNUC_CONST;
